#!/bin/sh
#
# code by ngc1927

export PATH=$PATH:/var/bin
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/var/lib

cd /tmp
insmod /var/lib/modules/smbfs.ko

/usr/bin/nmbd && /usr/bin/smbd && echo "Samba started" || echo "Error"

exit 0
