#!/bin/sh
#
# code by ngc1927

export PATH=$PATH:/var/bin
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:/var/lib

cd /tmp
rmmod smbfs 1>/dev/null  2>/dev/null


killall nmbd smbd 1>/dev/null  2>/dev/null && echo "Samba stopped"
kill -9 `pidof nmbd` && echo "nmbd stopped" || echo "Error"
kill -9 `pidof smbd` && echo "smbd stopped" || echo "Error"

exit 0
