#!/bin/sh
#
# code by ngc1927

rm -f /var/bin/scrplg-SYSTEM-Start_Samba.sh
rm -f /var/bin/scrplg-SYSTEM-Stop_Samba.sh

rm -f /var/etc/smb.conf.sif_example

rm -f /var/lib/modules/smbfs.ko

rm -f /var/uninstall/samba-9000HD_delfile.sh

exit 0
